@@ -116,10 +116,12 @@ power.HVNTID <- function(alpha=0.05, theta1, theta2, theta0, CV, n,
   chunks   <- 1
   nsi      <- nsims
   if (nsims>1E7) {
-    chunks <- round(nsims/1E7,0)
+    chunks <- ceiling(nsims/1E7)
     nsi    <- 1E7
   } 
   for (iter in 1:chunks) {
+    # if chunks*1E7 >nsims correct nsi to given nsims
+    if(iter==chunks) nsi <- nsims-(chunks-1)*nsi
     # simulate sample mean via its normal distribution
     means  <- rnorm(nsi, mean=mlog, sd=sdm)
     # simulate sample sd2s via chi-square distri
