@@ -137,7 +137,9 @@ sampleN.scABEL1 <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
     cat("alpha  = ", alpha,", target power = ", targetpower,"\n", sep="")
     cat("CVw(T) = ", CVwT,"; CVw(R) = ", CVwR,"\n", sep="")
     cat("True ratio = ",theta0,"\n", sep="")
-    cat("ABE limits / PE constraint =", theta1,"...", theta2,"\n")
+    cat("ABE limits / PE constraint =", theta1, "...", theta2, "\n")
+    if (reg$name == "GCC" & CVwR > 0.3)
+      cat("Widened limits =", 0.75, "...", 1/0.75, "\n")
     if (details | reg$name=="USER") { 
       print(reg)
       cat("\n")
@@ -148,7 +150,7 @@ sampleN.scABEL1 <- function(alpha=0.05, targetpower=0.8, theta0, theta1,
   
   # -----------------------------------------------------------------
   # nstart? from sampleN0 with widened limits
-  # does'nt fit really good if theta0>=1.2! ways out? see sampleN0.2
+  # doesn't fit really good if theta0>=1.2! ways out? see sampleN0.2
   ltheta1 <- -sqrt(s2wR)*r_const
   ltheta2 <- -ltheta1
   if (CVwR <= CVswitch){
