@@ -1,6 +1,7 @@
 #--------------------------------------------------------------------
 # Functions to simulate replicate cross-over data
 # fixed effects model (EMA)
+# may also be used for a 2x2 cross-over
 # 
 # Author: dlabes
 #--------------------------------------------------------------------
@@ -16,19 +17,20 @@
 # s2wT, s2wR = within-subject variances for "T" or "R"
 #
 # prepare a dataframe with subject, sequence, period, logval
+# result is sorted by sequences
 prep_data2 <- function(seqs, nseq, muR=log(10), ldiff, s2wT, s2wR)
 {
   n_seqs <- length(seqs)
   ns <- integer(length=n_seqs)
-  # if only one n is given repeat it for the sequences
+  # if only one nseq is given repeat it for the sequences
   if (length(nseq)==1) ns <- rep(nseq, times=n_seqs)  else ns <- nseq
   data <- data.frame()
   for (i in seq_along(seqs))
   { 
     pers <- nchar(seqs[i])
-    pervals <- rep(0,times=pers)
+    pervals <- rep(0, times=pers)
     tmt <- strsplit(seqs[i], split="")
-    pervals <- matrix(0,nseq[i],pers)
+    pervals <- matrix(0, nseq[i], pers)
     pdata <- data.frame(pervals)
     pdata$seqno    <- i
     pdata$sequence <- seqs[i]
@@ -48,11 +50,66 @@ prep_data2 <- function(seqs, nseq, muR=log(10), ldiff, s2wT, s2wR)
   
   ldata     <- ldata[,c("subject","seqno","sequence","period","tmt","logval")]
   
+  # simulate the logval
   ldata$logval <- sim_data2_y(data_tmt=ldata$tmt, muR=log(10), 
                               ldiff=ldiff, s2wT, s2wR)
   return(ldata)
 }
 
+# purpose as above but with alternating sequences to be used 
+# in models with group effects
+prep_data3 <- function(seqs, nseq, muR=log(10), ldiff, s2wT, s2wR)
+{
+  n_seqs <- length(seqs)
+  ns <- integer(length=n_seqs)
+  # if only one n is given repeat it for the sequences
+  if (length(nseq)==1) ns <- rep(nseq, times=n_seqs)  else ns <- nseq
+  N <- sum(ns)
+  subs <- 1:N # subjects
+  # next doesn't function if vector nseq contains different numbers
+  #seq  <- rep(seqs, times=ceiling(N/n_seqs))
+  #seq  <- seq[1:N] # procrustinate
+  # another try
+  subinseq <- vector("numeric")
+  seq <- vector("character")
+  seqno <- vector("numeric")
+  for(i in seq_along(seqs)){
+    subinseqi <- 1:nseq[i] # subjects numbered within sequence
+    seqi  <- rep(seqs[i], times=nseq[i])
+    subinseq <- c(subinseq, subinseqi)
+    seq   <- c(seq, seqi)
+    seqno <- c(seqno, rep.int(i, nseq[i]))
+  }
+  seq   <- seq[order(subinseq)]
+  seqno <- seqno[order(subinseq)]
+  data  <- data.frame(seqno=seqno, sequence=seq)
+  maxper <- max(nchar(seq))
+  # period values of the logval, here assumed as zero dummy
+  pervals <- matrix(0, nrow=N, ncol=maxper)
+  data <- cbind(pervals, data)
+  for(j in 1:ncol(pervals))
+  {
+    nam <- paste("P",j,sep="")
+    names(data)[j] <- nam
+  } 
+  # make the long form
+  ldata <- reshape(data, v.names="logval", varying=list(1:(ncol(data)-2)),
+                   timevar="period", idvar="subject", direction="long")
+  # order by subject, period
+  ldata     <- ldata[order(ldata$subject,ldata$period),]
+  # order by subject, period
+  ldata     <- ldata[order(ldata$subject,ldata$period),]
+  # extract the treatment from sequence
+  ldata$tmt <- substr(ldata$sequence, ldata$period, ldata$period)
+  # make column order
+  ldata     <- ldata[, c("subject", "seqno", "sequence", "period", "tmt", "logval")]
+  # simulate the logval
+  ldata$logval <- sim_data2_y(data_tmt=ldata$tmt, muR=log(10), 
+                              ldiff=ldiff, s2wT, s2wR)
+  return(ldata)
+  
+} # end function prep_data3
+
 # get new values for logval
 sim_data2 <- function(data, muR=log(10), ldiff, s2wT, s2wR)
 {
